@@ -1,10 +1,13 @@
 #' @noRd
 #' @title Select the specified column per row
 #' @keywords internal
-rowColumns = function(x, i) {
-  assert_that(is.matrix(x) && all(is.finite(i)))
-  assert_that(length(i) == nrow(x) &&
-                max(i) <= nrow(x) && min(i) >= 1)
+.rowColumns = function(x, i) {
+  assert_that(
+    is.matrix(x),
+    all(is.finite(i)),
+    length(i) == nrow(x),
+    max(i) <= nrow(x) && min(i) >= 1
+  )
   x[cbind(1:nrow(x), i)]
 }
 
@@ -39,7 +42,7 @@ setMethod('trajectoryAssignments', signature('matrix'), function(object, strateg
 
 
 #' @export
-#' @title Convert a repeated measures data matrix to a data.frame
+#' @title Convert a multiple time series matrix to a data.frame
 #' @param data The `matrix` containing a trajectory on each row.
 #' @param id The id column name.
 #' @param time The time column name.
@@ -48,13 +51,16 @@ setMethod('trajectoryAssignments', signature('matrix'), function(object, strateg
 #' @param times A `numeric` `vector` specifying the times of the measurements. Should match the number of columns of `data`.
 #' @param as.data.table Whether to return the result as a `data.table`, or a `data.frame` otherwise.
 #' @return A `data.table` or `data.frame` containing the repeated measures.
-meltRepeatedMeasures = function(data,
-                                response,
-                                id = getOption('latrend.id'),
-                                time = getOption('latrend.time'),
-                                ids = rownames(data),
-                                times = colnames(data),
-                                as.data.table = FALSE) {
+#' @seealso [tsmatrix]
+tsframe = function(
+    data,
+    response,
+    id = getOption('latrend.id'),
+    time = getOption('latrend.time'),
+    ids = rownames(data),
+    times = colnames(data),
+    as.data.table = FALSE
+) {
   assert_that(
     is.matrix(data),
     is.character(id),
@@ -112,30 +118,67 @@ meltRepeatedMeasures = function(data,
   }
 }
 
+#' @rdname tsframe
+#' @note The `meltRepeatedMeasures()` function is deprecated and will be removed in a future version, please use `tsframe()` instead.
+meltRepeatedMeasures = tsframe
+
 #' @export
-#' @title Cast a longitudinal data.frame to a matrix
+#' @title Convert a longitudinal data.frame to a matrix
 #' @description Converts a longitudinal `data.frame` comprising trajectories with an equal number of observations, measured at identical moments in time, to a `matrix`. Each row of the matrix represents a trajectory.
-#' @inheritParams meltRepeatedMeasures
+#' @inheritParams tsframe
+#' @param fill A `scalar` value. If `FALSE`, an error is thrown when time series observations are missing in the data frame.
+#' Otherwise, the value used for representing missing observations.
 #' @return A `matrix` with a trajectory per row.
-dcastRepeatedMeasures = function(data,
-                                 response,
-                                 id = getOption('latrend.id'),
-                                 time = getOption('latrend.time')) {
-  assert_that(has_name(data, c(id, time, response)))
+#' @seealso [tsframe]
+tsmatrix = function(
+    data,
+    response,
+    id = getOption('latrend.id'),
+    time = getOption('latrend.time'),
+    fill = NA
+) {
+  assert_that(
+    is.data.frame(data),
+    has_name(data, c(id, time, response)),
+    nrow(data) > 0,
+    is.scalar(fill),
+    noNA(data[[id]]),
+    noNA(data[[time]])
+  )
 
   dt = as.data.table(data)
   setkeyv(dt, c(id, time))
 
-  numIds = uniqueN(dt[[id]])
-  numTime = uniqueN(dt[[time]])
-  assert_that(all(dt[, .N, by=c(id)]$N == numTime), msg = 'trajectories do not all have the same number of observations')
+  ids = unique(dt[[id]])
+  times = unique(dt[[time]])
 
-  dataMat = matrix(dt[[response]],
-                   byrow = TRUE,
-                   nrow = uniqueN(dt[[id]]),
-                   ncol = uniqueN(dt[[time]]))
+  if (isFALSE(fill)) {
+    assert_that(
+      are_trajectories_equal_length(dt, id = id, time = time)
+    )
+  } else if (!are_trajectories_equal_length(dt, id = id, time = time)) {
+    # insert missing observations
+    dt[, .Fill := FALSE]
+    dtIndex = CJ(ids, times)
+    setnames(dtIndex, c(id, time))
+    dt = dt[dtIndex]
+    dt[is.na(.Fill), c(response) := fill]
+    dt[, .Fill := NULL]
+  }
 
-  rownames(dataMat) = unique(dt[[id]])
-  colnames(dataMat) = unique(dt[[time]])
-  return(dataMat)
+  dataMat = matrix(
+    dt[[response]],
+    byrow = TRUE,
+    nrow = length(ids),
+    ncol = length(times)
+  )
+
+  rownames(dataMat) = ids
+  colnames(dataMat) = times
+
+  dataMat
 }
+
+#' @rdname tsmatrix
+#' @note The `dcastRepeatedMeasures()` function is deprecated and will be removed in a future version. Please use `tsmatrix()` instead.
+dcastRepeatedMeasures = tsmatrix
